@@ -202,6 +202,20 @@ class deviceModule(ranaModule):
     """
     pass
 
+  def getInternetConnectivityStatus(self):
+    """report the current status of internet connectivity on the device
+    None - status reporting not supported or status unknown
+    True - connected to the Internet
+    False - disconnected from the Internet
+    """
+
+  def enableInternetConnectivity(self):
+    """try to make sure that the device connects to the internet"""
+    # TODO: respect the modRana internet connectivity state
+    pass
+
+
+
 #  def getAutorotationSupported(self):
 #    return False
 #
