@@ -18,6 +18,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
+import traceback
+import sys
 from base_module import ranaModule
 import cPickle
 import os
@@ -26,7 +28,7 @@ import csv
 from point import Point
 
 def getModule(m,d,i):
-  return(storePOI(m,d,i))
+  return storePOI(m,d,i)
 
 class storePOI(ranaModule):
   """Store POI data."""
@@ -393,7 +395,7 @@ class storePOI(ranaModule):
   def dumpToCSV(self):
     """dump the db content as a CSV file"""
     units = self.m.get('units', None)
-    POIFolderPath = self.dmod.getPOIFolderPath()
+    POIFolderPath = self.modrana.paths.getPOIFolderPath()
     self.sendMessage('ml:notification:m:POI export starting;5')
     if units and self.db:
       try:
@@ -421,7 +423,9 @@ class storePOI(ranaModule):
 
         self.sendMessage('ml:notification:m:POI exported to: %s;5' % POIFolderPath)
       except Exception, e:
-        print "storePOI: CSV dump failed:\n%s" % e
+        print("storePOI: CSV dump failed")
+        print(e)
+        traceback.print_exc(file=sys.stdout)
         self.sendMessage('ml:notification:m:POI export failed;5')
 
   def shutdown(self):
@@ -468,7 +472,7 @@ class storePOI(ranaModule):
       for addressLine in result['addressLines']:
         text += "\n%s" % addressLine
     except:
-      text += "\n%s" % "no adress found"
+      text += "\n%s" % "no address found"
 
     try: # it seems, that this entry is no guarantied
       for phoneNumber in result['phoneNumbers']:
@@ -505,10 +509,3 @@ class POI():
   def setDescription(self, description):
     self.description = description
 #    self.GLSResult = None # optional
-
-
-if(__name__ == "__main__"):
-  a = example({}, {})
-  a.update()
-  a.update()
-  a.update()
